diff --git a/src/template-parts/single-items-attachments.php b/src/template-parts/single-items-attachments.php
index 2062c6e..c332e9b 100644
--- a/src/template-parts/single-items-attachments.php
+++ b/src/template-parts/single-items-attachments.php
@@ -67,8 +67,8 @@
'item-card--thumbnail mt-2'));
echo '
';
- echo __( 'Document', 'tainacan-interface' );
?>
+
@@ -77,8 +77,8 @@
ID, 'tainacan-interface-item-attachments', true );
echo '
';
- echo get_the_title( $attachment->ID );
?>
+ ID ); ?>
@@ -103,8 +103,8 @@
ID, 'tainacan-interface-item-attachments', true );
echo '
';
- echo get_the_title( $attachment->ID );
?>
+ ID ); ?>
diff --git a/src/functions/customizer.php b/src/functions/customizer.php
index f9a38d6..9c9bb26 100644
--- a/src/functions/customizer.php
+++ b/src/functions/customizer.php
@@ -414,7 +414,24 @@ function tainacan_customize_register( $wp_customize ) {
) );
/**
- * Adds options to display item autohr and publish date.
+ * Adds options to hide attachments file names on carousel.
+ */
+ $wp_customize->add_setting( 'tainacan_single_item_hide_files_name', array(
+ 'type' => 'theme_mod',
+ 'capability' => 'edit_theme_options',
+ 'default' => false,
+ 'transport' => 'refresh'
+ ) );
+ $wp_customize->add_control( 'tainacan_single_item_hide_files_name', array(
+ 'type' => 'checkbox',
+ 'priority' => 3, // Within the section.
+ 'section' => 'tainacan_single_item_page',
+ 'label' => __( 'Hide the attchments label', 'tainacan-interface' ),
+ 'description' => __( 'Toggle to not display the document and attachments name below its thumbnail.', 'tainacan-interface' )
+ ) );
+
+ /**
+ * Adds options to display item author and publish date.
*/
$wp_customize->add_setting( 'tainacan_single_item_hide_item_meta', array(
'type' => 'theme_mod',